@@ -209,6 +209,11 @@ types: list[str] = [
     "AWS::Config::OrganizationConformancePack",
     "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
+    "AWS::Connect::ApprovedOrigin",
+    "AWS::Connect::Instance",
+    "AWS::Connect::InstanceStorageConfig",
+    "AWS::Connect::IntegrationAssociation",
+    "AWS::Connect::SecurityKey",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
@@ -700,6 +705,7 @@ types: list[str] = [
     "AWS::SES::EmailIdentity",
     "AWS::SES::MailManagerAddonInstance",
     "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
     "AWS::SES::MailManagerArchive",
     "AWS::SES::MailManagerIngressPoint",
     "AWS::SES::MailManagerRelay",
@@ -1071,6 +1077,11 @@ cached: list[str] = [
     "aws-config-organizationconformancepack.json",
     "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
+    "aws-connect-approvedorigin.json",
+    "aws-connect-instance.json",
+    "aws-connect-instancestorageconfig.json",
+    "aws-connect-integrationassociation.json",
+    "aws-connect-securitykey.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
     "aws-controltower-landingzone.json",
@@ -1104,6 +1115,7 @@ cached: list[str] = [
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
+    "aws-ec2-clientvpnendpoint.json",
     "aws-ec2-clientvpnroute.json",
     "aws-ec2-clientvpntargetnetworkassociation.json",
     "aws-ec2-customergateway.json",
@@ -1118,6 +1130,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1345,6 +1358,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1358,6 +1372,7 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
@@ -1611,6 +1626,7 @@ cached: list[str] = [
     "aws-ses-emailidentity.json",
     "aws-ses-mailmanageraddoninstance.json",
     "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
     "aws-ses-mailmanagerarchive.json",
     "aws-ses-mailmanageringresspoint.json",
     "aws-ses-mailmanagerrelay.json",
@@ -1633,6 +1649,7 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -1667,6 +1684,9 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
