@@ -354,6 +354,7 @@ types: list[str] = [
     "AWS::DataZone::Owner",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::ProjectProfile",
     "AWS::DataZone::SubscriptionTarget",
     "AWS::DataZone::UserProfile",
     "AWS::Deadline::Farm",
@@ -769,6 +770,7 @@ types: list[str] = [
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
     "AWS::Lightsail::Instance",
+    "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
     "AWS::Lightsail::LoadBalancerTlsCertificate",
     "AWS::Lightsail::StaticIp",
@@ -1081,6 +1083,7 @@ types: list[str] = [
     "AWS::SES::EmailIdentity",
     "AWS::SES::MailManagerAddonInstance",
     "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
     "AWS::SES::MailManagerArchive",
     "AWS::SES::MailManagerIngressPoint",
     "AWS::SES::MailManagerRelay",
@@ -1630,6 +1633,7 @@ cached: list[str] = [
     "aws-datazone-owner.json",
     "aws-datazone-project.json",
     "aws-datazone-projectmembership.json",
+    "aws-datazone-projectprofile.json",
     "aws-datazone-subscriptiontarget.json",
     "aws-datazone-userprofile.json",
     "aws-dax-cluster.json",
@@ -1671,7 +1675,6 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
-    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -1692,6 +1695,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1864,6 +1868,8 @@ cached: list[str] = [
     "aws-fsx-volume.json",
     "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
+    "aws-gamelift-fleet.json",
+    "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
     "aws-gamelift-script.json",
@@ -2052,6 +2058,7 @@ cached: list[str] = [
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
     "aws-lightsail-instance.json",
+    "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
@@ -2075,6 +2082,7 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-lookoutmetrics-alert.json",
     "aws-lookoutmetrics-anomalydetector.json",
     "aws-m2-application.json",
@@ -2337,6 +2345,7 @@ cached: list[str] = [
     "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
+    "aws-s3express-accesspoint.json",
     "aws-s3express-bucketpolicy.json",
     "aws-s3express-directorybucket.json",
     "aws-s3objectlambda-accesspoint.json",
@@ -2431,6 +2440,7 @@ cached: list[str] = [
     "aws-ses-emailidentity.json",
     "aws-ses-mailmanageraddoninstance.json",
     "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
     "aws-ses-mailmanagerarchive.json",
     "aws-ses-mailmanageringresspoint.json",
     "aws-ses-mailmanagerrelay.json",
