@@ -43,10 +43,15 @@ types: list[str] = [
     "AWS::AppConfig::ExtensionAssociation",
     "AWS::AppConfig::HostedConfigurationVersion",
     "AWS::AppSync::Api",
+    "AWS::AppSync::ApiCache",
+    "AWS::AppSync::ApiKey",
     "AWS::AppSync::ChannelNamespace",
+    "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
     "AWS::AppSync::FunctionConfiguration",
+    "AWS::AppSync::GraphQLApi",
+    "AWS::AppSync::GraphQLSchema",
     "AWS::AppSync::Resolver",
     "AWS::AppSync::SourceApiAssociation",
     "AWS::ApplicationAutoScaling::ScalableTarget",
@@ -124,6 +129,10 @@ types: list[str] = [
     "AWS::DataSync::Agent",
     "AWS::DataSync::LocationAzureBlob",
     "AWS::DataSync::LocationEFS",
+    "AWS::DataSync::LocationFSxLustre",
+    "AWS::DataSync::LocationFSxONTAP",
+    "AWS::DataSync::LocationFSxOpenZFS",
+    "AWS::DataSync::LocationFSxWindows",
     "AWS::DataSync::LocationHDFS",
     "AWS::DataSync::LocationNFS",
     "AWS::DataSync::LocationObjectStorage",
@@ -541,10 +550,13 @@ cached: list[str] = [
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-appsync-api.json",
+    "aws-appsync-apicache.json",
+    "aws-appsync-apikey.json",
     "aws-appsync-channelnamespace.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
+    "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
@@ -553,6 +565,7 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -611,6 +624,10 @@ cached: list[str] = [
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
     "aws-datasync-locationefs.json",
+    "aws-datasync-locationfsxlustre.json",
+    "aws-datasync-locationfsxontap.json",
+    "aws-datasync-locationfsxopenzfs.json",
+    "aws-datasync-locationfsxwindows.json",
     "aws-datasync-locationhdfs.json",
     "aws-datasync-locationnfs.json",
     "aws-datasync-locationobjectstorage.json",
@@ -788,6 +805,7 @@ cached: list[str] = [
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
+    "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -820,6 +838,7 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
@@ -887,7 +906,6 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-resolverconfig.json",
-    "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
     "aws-route53resolver-resolverrule.json",
@@ -927,6 +945,7 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
