@@ -45,6 +45,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -826,6 +827,7 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
@@ -909,6 +911,7 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -923,6 +926,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -950,7 +954,6 @@ cached: list[str] = [
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
-    "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
@@ -989,7 +992,6 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1032,6 +1034,7 @@ cached: list[str] = [
     "aws-emr-studiosessionmapping.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-events-archive.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -1047,6 +1050,8 @@ cached: list[str] = [
     "aws-fsx-volume.json",
     "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
+    "aws-gamelift-fleet.json",
+    "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-matchmakingconfiguration.json",
     "aws-gamelift-matchmakingruleset.json",
@@ -1312,6 +1317,7 @@ cached: list[str] = [
     "aws-s3-bucketpolicy.json",
     "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
+    "aws-s3express-accesspoint.json",
     "aws-s3express-bucketpolicy.json",
     "aws-s3express-directorybucket.json",
     "aws-s3objectlambda-accesspoint.json",
