@@ -52,6 +52,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -887,9 +888,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -900,12 +899,9 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1007,7 +1003,6 @@ cached: list[str] = [
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
-    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -1032,6 +1027,7 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
+    "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
     "aws-codecommit-repository.json",
@@ -1341,6 +1337,7 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalytics-applicationoutput.json",
@@ -1360,7 +1357,6 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
@@ -1379,6 +1375,7 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
@@ -1603,6 +1600,7 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -1636,6 +1634,9 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
