@@ -51,6 +51,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -871,9 +872,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -884,12 +883,9 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1361,6 +1357,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1374,6 +1371,7 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-macie-allowlist.json",
     "aws-macie-session.json",
     "aws-msk-batchscramsecret.json",
@@ -1590,6 +1588,7 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
