@@ -549,6 +549,7 @@ types: list[str] = [
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
     "AWS::LaunchWizard::Deployment",
+    "AWS::Lex::Bot",
     "AWS::Lex::BotAlias",
     "AWS::Lex::BotVersion",
     "AWS::Lex::ResourcePolicy",
@@ -624,6 +625,7 @@ types: list[str] = [
     "AWS::Organizations::ResourcePolicy",
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
+    "AWS::PCS::Cluster",
     "AWS::Pinpoint::ADMChannel",
     "AWS::Pinpoint::APNSChannel",
     "AWS::Pinpoint::APNSSandboxChannel",
@@ -1087,7 +1089,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1193,6 +1194,7 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
@@ -1412,6 +1414,7 @@ cached: list[str] = [
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
+    "aws-pcs-cluster.json",
     "aws-pinpoint-apnschannel.json",
     "aws-pinpoint-apnssandboxchannel.json",
     "aws-pinpoint-apnsvoipchannel.json",
@@ -1444,6 +1447,9 @@ cached: list[str] = [
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
+    "aws-rds-dbproxy.json",
+    "aws-rds-dbproxyendpoint.json",
+    "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
@@ -1498,7 +1504,6 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
-    "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-domain.json",
@@ -1572,6 +1577,7 @@ cached: list[str] = [
     "aws-sqs-queue.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -1591,7 +1597,6 @@ cached: list[str] = [
     "aws-stepfunctions-statemachineversion.json",
     "aws-synthetics-group.json",
     "aws-timestream-database.json",
-    "aws-timestream-scheduledquery.json",
     "aws-timestream-table.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
